@@ -2,7 +2,7 @@ use 5.14.0;
 
 package Map::Metro::Plugin::Map::Oslo;
 
-our $VERSION = '0.1103'; # VERSION
+our $VERSION = '0.1104'; # VERSION
 # ABSTRACT: Map::Metro map for Oslo
 
 use Moose;
@@ -31,9 +31,24 @@ __END__
 
 Map::Metro::Plugin::Map::Oslo - Map::Metro map for Oslo
 
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.16+-brightgreen.svg" alt="Requires Perl 5.16+" /> <a href="https://travis-ci.org/Csson/p5-Map-Metro-Oslo"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Oslo.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-69.2%-red.svg" alt="coverage 69.2%" /></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.16+](https://img.shields.io/badge/perl-5.16+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Map-Metro-Oslo.svg?branch=master)](https://travis-ci.org/Csson/p5-Map-Metro-Oslo) ![coverage 69.2%](https://img.shields.io/badge/coverage-69.2%-red.svg)
+
+=end markdown
+
 =head1 VERSION
 
-Version 0.1103, released 2015-01-22.
+Version 0.1104, released 2016-01-24.
 
 =head1 SYNOPSIS
 
@@ -80,7 +95,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
